import { defHttp } from '@/utils/http/axios';
import {
  GetUserListModel,
  tableParams,
  sendingMailModel,
  addAccountParams,
} from './model/userListModel';

enum Api {
  GET_USER_LIST = '/crm/email/getUserList',
  SENDING_MAIL_DO = '/crm/mail/sendingMail.do',
  UPDATE_READ = '/crm/mail/updateRead.do',
  RECEIVE = '/crm/mail/receive.do',
  SAVE_MAIL_DRAFTS = '/crm/mail/saveMailDrafts.do',
  ADD_ACCOUNT = '/crm/mail/account/addAccount.do',
  GET_ACCOUNT = '/crm/mail/account/getAccount.do',
  UPDATE_ACCOUNT = '/crm/mail/account/updateAccount.do',
  DELETE_ACCOUNT = '/crm/mail/account/deleteAccount.do',
  GET_ACCOUNT_LIST = '/crm/mail/account/getAccountList.do',
  IS_EMAIL_VALID = '/crm/mail/account/isEmailValid.do',
  GET_EMAIL_MODULE = '/crm/mail/getEmailModule.do',
  ADD_SIGNATURE = '/crm/mail/signature/addSignature.do',
  UPDATE_SIGNATURE = '/crm/mail/signature/updateSignature.do',
  GET_SIGNATURE = '/crm/mail/signature/getSignature.do',
  ADD_QUICK_TEXT = '/crm/mail/quickText/addQuickText.do',
  UPDATE_QUICK_TEXT = '/crm/mail/quickText/updateQuickText.do',
  GET_QUICK_TEXT = '/crm/mail/quickText/getQuickText.do',
  DELETE_QUICK_TEXT = '/crm/mail/quickText/deleteQuickText.do',
  GET_MAIL_LIST = '/crm/mail/getMailList.do',
  GET_USER_INFO = '/crm/base/userInfo.do',
  GET_MAIL_INFO = '/crm/mail/getMailInfo.do',
  EMAIL_LIST = '/crm/base/emailList.do',
  UPDATE_HANDLE = '/crm/mail/updateHandle.do',
  DELETE_EMAIL = '/crm/mail/deleteEmail.do',
  SET_QUICK_REPLY = '/crm/mail/setQuickReply.do',
  CONTACT_LIST = '/crm/clues/contactList.do',
  GET_HANDLE_MAIL_LIST = '/crm/mail/getHandleMailList.do',
  ADD_FOLDER = '/crm/mail/folder/addFolder.do',
  UPDATE_FOLDER = '/crm/mail/folder/updateFolder.do',
  DELETE_FOLDER = '/crm/mail/folder/deleteFolder.do',
  GET_FOLDER = '/crm/mail/folder/getFolder.do',
  GET_ROW_ID = '/getRowid.do',
  ADD_TAG = '/crm/mail/tag/addTag.do',
  UPDATE_TAG = '/crm/mail/tag/updateTag.do',
  DELETE_TAG = '/crm/mail/tag/deleteTag.do',
  GET_TAG = '/crm/mail/tag/getTagList.do',
  ADD_BLACKLIST = '/crm/mail/blacklist/addBlackList.do',
  UPDATE_BLACKLIST = '/crm/mail/blacklist/updateBlackList.do',
  DELETE_BLACKLIST = '/crm/mail/blacklist/deleteBlackList.do',
  GET_BLACKLIST = '/crm/mail/blacklist/getBlackList.do',
  GET_EMAIL_MODULE_BELOW = '/crm/mail/getEmailModuleBelow.do',
}
// 获取邮件路由列表
export const getEmailModuleApi = () => defHttp.get({ url: Api.GET_EMAIL_MODULE });

export const receiveApi = (params) => defHttp.get({ url: Api.RECEIVE, params });
//获取联系人列表
export const getUserListApi = (params: tableParams) =>
  defHttp.post<GetUserListModel[]>({ url: Api.GET_USER_LIST, params });
// 发送邮件
export const sendingMailApi = (params) =>
  defHttp.post<sendingMailModel[]>({ url: Api.SENDING_MAIL_DO, params });
export const updateReadApi = (params) => defHttp.post<{}>({ url: Api.UPDATE_READ, params });
// 草稿箱
export const saveMailDraftsApi = (params) =>
  defHttp.post<{}>({ url: Api.SAVE_MAIL_DRAFTS, params });

// 添加邮箱配置
export const addAccountApi = (params: addAccountParams) =>
  defHttp.post<{}>({ url: Api.ADD_ACCOUNT, params });
// 获取邮箱配置
export const getAccountApi = (params) => defHttp.get<{}>({ url: Api.GET_ACCOUNT, params });
// 修改邮箱配置
export const updateAccountApi = (params) => defHttp.post<{}>({ url: Api.UPDATE_ACCOUNT, params });
// 删除邮箱配置
export const deleteAccountApi = (params) => defHttp.post<{}>({ url: Api.DELETE_ACCOUNT, params });

// 获取邮箱列表
export const getAccountListApi = () => defHttp.get<{}>({ url: Api.GET_ACCOUNT_LIST });
// 检测邮箱
export const isEmailValidApi = (params) =>
  defHttp.get({
    url: Api.IS_EMAIL_VALID,
    params,
  });

// 添加签名
export const addSignatureApi = (params) =>
  defHttp.post({
    url: Api.ADD_SIGNATURE,
    params,
  });
// 修改签名
export const updateSignatureApi = (params) =>
  defHttp.post({
    url: Api.UPDATE_SIGNATURE,
    params,
  });

// 查询签名
export const getSignatureApi = (params) =>
  defHttp.get({
    url: Api.GET_SIGNATURE,
    params,
  });

// 查询快速文本
export const getQuickTextApi = (params) =>
  defHttp.get({
    url: Api.GET_QUICK_TEXT,
    params,
  });
// 新增快速文本
export const addQuickTextApi = (params) =>
  defHttp.post({
    url: Api.ADD_QUICK_TEXT,
    params,
  });
// 更新快速文本
export const updateQuickTextApi = (params) =>
  defHttp.post({
    url: Api.UPDATE_QUICK_TEXT,
    params,
  });
// 删除快速文本
export const deleteQuickTextApi = (params) =>
  defHttp.post({
    url: Api.DELETE_QUICK_TEXT,
    params,
  });

// 获取邮件列表
export const getMailListApi = (params) =>
  defHttp.get({
    url: Api.GET_MAIL_LIST,
    params,
  });

// 获取企业同事列表
export const getUserInfoApi = (params) =>
  defHttp.post({
    url: Api.GET_USER_INFO,
    params,
  });

// 获取邮件详情
export const getMailInfoApi = (params) =>
  defHttp.get({
    url: Api.GET_MAIL_INFO,
    params,
  });

// 获取模糊搜索人员
export const emailListAPi = (params) =>
  defHttp.post({
    url: Api.EMAIL_LIST,
    params,
  });
// 设置完成时间
export const updateHandleAPi = (params) =>
  defHttp.get({
    url: Api.UPDATE_HANDLE,
    params,
  });
// 删除邮件
export const deleteEmailAPi = (params) =>
  defHttp.post({
    url: Api.DELETE_EMAIL,
    params,
  });

// 快速回复
export const setQuickReplyAPi = (params) =>
  defHttp.post({
    url: Api.SET_QUICK_REPLY,
    params,
  });

// 获取线索联系人列表
export const contactListAPi = (params) =>
  defHttp.post({
    url: Api.CONTACT_LIST,
    params,
  });

// 获取线索联系人列表
export const getHandleMailListApi = (params) =>
  defHttp.get({
    url: Api.GET_HANDLE_MAIL_LIST,
    params,
  });

// 新增文件夹
export const addFolderApi = (params) =>
  defHttp.post({
    url: Api.ADD_FOLDER,
    params,
  });

// 修改文件夹
export const updateFolderApi = (params) =>
  defHttp.post({
    url: Api.UPDATE_FOLDER,
    params,
  });

// 删除文件夹
export const deleteFolderApi = (params) =>
  defHttp.post({
    url: Api.DELETE_FOLDER,
    params,
  });

// 查询文件夹
export const getFolderApi = (params) =>
  defHttp.get({
    url: Api.GET_FOLDER,
    params,
  });

// 获取rowId
export const getRowIdApi = () =>
  defHttp.get({
    url: Api.GET_ROW_ID,
  });

// 新增标签
export const addTagApi = (params) =>
  defHttp.post({
    url: Api.ADD_TAG,
    params,
  });

// 修改标签
export const updateTagApi = (params) =>
  defHttp.post({
    url: Api.UPDATE_TAG,
    params,
  });

// 删除标签
export const deleteTagApi = (params) =>
  defHttp.post({
    url: Api.DELETE_TAG,
    params,
  });

// 查询标签
export const getTagApi = (params) =>
  defHttp.get({
    url: Api.GET_TAG,
    params,
  });


// 新增黑名单
export const addBlackListApi = (params) =>
  defHttp.post({
    url: Api.ADD_BLACKLIST,
    params,
  });

// 修改黑名单
export const updateBlackListApi = (params) =>
  defHttp.post({
    url: Api.UPDATE_BLACKLIST,
    params,
  });

// 删除黑名单
export const deleteBlackListApi = (params) =>
  defHttp.post({
    url: Api.DELETE_BLACKLIST,
    params,
  });

// 查询黑名单
export const getBlackListApi = (params) =>
  defHttp.get({
    url: Api.GET_BLACKLIST,
    params,
  });


  export const getEmailModuleBelowApi = () =>
    defHttp.get({
      url: Api.GET_EMAIL_MODULE_BELOW,
    });
  